@@ -134,12 +134,7 @@ class Job(BaseModel):
 
     @property
     def is_done(self) -> bool:
-        return self.status.current in {
-            CurrentJobStatus.failed,
-            CurrentJobStatus.exited,
-            CurrentJobStatus.canceled,
-            CurrentJobStatus.finalized,
-        }
+        return self.status.current == CurrentJobStatus.finalized
 
     def check(self):
         """
@@ -147,16 +142,14 @@ class Job(BaseModel):
         """
         from ..exceptions import JobFailedError
 
-        if self.status.current in {CurrentJobStatus.failed, CurrentJobStatus.canceled}:
-            raise JobFailedError(f"Job '{self.id}' {self.status.current}")
-        elif (
-            self.status.current in {CurrentJobStatus.finalized, CurrentJobStatus.exited}
-            and self.status.exit_code is not None
-            and self.status.exit_code > 0
-        ):
+        if self.status.exit_code is not None and self.status.exit_code > 0:
             raise JobFailedError(
                 f"Job '{self.id}' exited with non-zero exit code ({self.status.exit_code})"
             )
+        elif self.status.canceled is not None:
+            raise JobFailedError(f"Job '{self.id}' was canceled")
+        elif self.status.failed is not None:
+            raise JobFailedError(f"Job '{self.id}' failed")
 
 
 class Jobs(BaseModel):
